# ContextData
[![stars](https://badgen.net/github/stars/Avivsalem/ContextData)](https://github.com/Avivsalem/ContextData/stargazers)
[![license](https://badgen.net/github/license/Avivsalem/ContextData/)](https://github.com/Avivsalem/ContextData/blob/main/LICENSE)
[![last commit](https://badgen.net/github/last-commit/Avivsalem/ContextData/main)](https://github.com/Avivsalem/ContextData/commit/main)
[![tests](https://github.com/Avivsalem/ContextData/actions/workflows/tests.yml/badge.svg)](https://github.com/Avivsalem/ContextData/actions/workflows/tests.yml?query=branch%3Amain)
[![pypi version](https://badgen.net/pypi/v/contextdata)](https://pypi.org/project/contextdata/)
[![python compatibility](https://badgen.net/pypi/python/contextdata)](https://pypi.org/project/contextdata/)
[![downloads](https://img.shields.io/pypi/dm/contextdata)](https://pypi.org/project/contextdata/)

a package to manage contextual data across your program, and output it to logs
